Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
src / __init__.py |  | 1 | 0 | 0 |  | 100%
src / analytics / __init__.py |  | 0 | 0 | 0 |  | 100%
src / analytics / geo_analyzer.py |  | 2 | 0 | 0 |  | 100%
src / analytics / gsc_connector.py |  | 2 | 2 | 0 |  | 0%
src / analytics / metrics_tracker.py |  | 36 | 4 | 0 |  | 89%
src / analytics / reporter.py |  | 2 | 0 | 0 |  | 100%
src / cli.py |  | 18 | 4 | 2 |  | 78%
src / content_generator / __init__.py |  | 0 | 0 | 0 |  | 100%
src / content_generator / geo_optimizer.py |  | 41 | 1 | 0 |  | 98%
src / content_generator / schema_builder.py |  | 11 | 0 | 0 |  | 100%
src / content_generator / seo_optimizer.py |  | 85 | 1 | 0 |  | 99%
src / content_generator / template_engine.py |  | 14 | 3 | 0 |  | 79%
src / keyword_research / __init__.py |  | 0 | 0 | 0 |  | 100%
src / keyword_research / analyzer.py |  | 44 | 1 | 2 |  | 98%
src / keyword_research / batch_processor.py |  | 40 | 4 | 2 |  | 90%
src / keyword_research / google_planner.py |  | 51 | 0 | 0 |  | 100%
src / platform_adapter / __init__.py |  | 0 | 0 | 0 |  | 100%
src / platform_adapter / base_adapter.py |  | 23 | 2 | 0 |  | 91%
src / platform_adapter / linkedin_adapter.py |  | 9 | 0 | 0 |  | 100%
src / platform_adapter / medium_adapter.py |  | 9 | 0 | 0 |  | 100%
src / platform_adapter / quora_adapter.py |  | 9 | 0 | 0 |  | 100%
src / platform_adapter / reddit_adapter.py |  | 9 | 0 | 0 |  | 100%
src / platform_adapter / twitter_adapter.py |  | 25 | 0 | 0 |  | 100%
src / utils / __init__.py |  | 3 | 0 | 0 |  | 100%
src / utils / config.py |  | 43 | 5 | 0 |  | 88%
src / utils / logger.py |  | 22 | 0 | 0 |  | 100%
src / utils / rate_limiter.py |  | 43 | 2 | 0 |  | 95%
src / utils / validators.py |  | 55 | 1 | 0 |  | 98%
Total |  | 597 | 30 | 6 |  | 95%

No items found using the specified filter.